@@ -32,38 +32,38 @@
 #' If the optimizer does not converge, model estimation will switch to the Expectation
 #' Maximization (EM) algorithm.
 #'
-#' Statistically significant correlation coefficients are shown in boldface on the
-#' console (\code{sig = TRUE}). However, this option is not supported when using
-#' R Markdown, i.e., the argument \code{sig} will switch to \code{FALSE}.
+#' Statistically significant correlation coefficients can be shown in boldface on
+#' the console when specifying \code{sig = TRUE}. However, this option is not supported
+#' when using R Markdown, i.e., the argument \code{sig} will switch to \code{FALSE}.
 #'
 #' Adjustment method for multiple testing when specifying the argument \code{p.adj}
-#' is applied to the within-group and between-broup correlation matrix separately.
+#' is applied to the within-group and between-group correlation matrix separately.
 #'
 #' @param x           a matrix or data frame.
-#' @param cluster     a vector representing the nested grouping structure (i.e., group or
-#'                    cluster variable).
-#' @param within      a character vector representing variables that are measured on the
-#'                    within level and modeled only on the within level. Variables not
-#'                    mentioned in \code{within} or \code{between} are measured on
-#'                    the within level and will be modeled on both the within and
-#'                    between level.
-#' @param between     a character vector representing variables that are measured on the
-#'                    between level and modeled only on the between level. Variables not
-#'                    mentioned in \code{within} or \code{between} are measured on
-#'                    the within level and will be modeled on both the within and
-#'                    between level.
+#' @param cluster     a vector representing the nested grouping structure (i.e.,
+#'                    group or cluster variable).
+#' @param within      a character vector representing variables that are measured
+#'                    on the within level and modeled only on the within level.
+#'                    Variables not mentioned in \code{within} or \code{between}
+#'                    are measured on the within level and will be modeled on both
+#'                    the within and between level.
+#' @param between     a character vector representing variables that are measured
+#'                    on the between level and modeled only on the between level.
+#'                    Variables not mentioned in \code{within} or \code{between}
+#'                    are measured on the within level and will be modeled on both
+#'                    the within and between level.
 #' @param estimator   a character string indicating the estimator to be used: \code{"ML"}
 #'                    for maximum likelihood and \code{"MLR"} (default) for maximum
 #'                    likelihood with Huber-White robust standard errors. Note that
 #'                    incomplete cases are removed listwise (i.e., \code{na.omit = TRUE})
-#'                    when using \code{"MLR"}, whereas full information maximum likelihood
-#'                    (FIML) is used to deal with missing data when using \code{"ML}
-#'                    when specifying \code{na.omit = FALSE}.
+#'                    when using \code{"MLR"}, whereas full information maximum
+#'                    likelihood (FIML) is used to deal with missing data when using
+#'                    \code{"ML} when specifying \code{na.omit = FALSE}.
 #' @param na.omit     logical: if \code{TRUE}, incomplete cases are removed before
 #'                    conducting the analysis (i.e., listwise deletion); if \code{FALSE}
 #'                    (default), full information maximum likelihood (FIML) is used
 #'                    when specifying \code{estimator = "ML"}.
-#' @param sig         logical: if \code{TRUE} (default), statistically significant
+#' @param sig         logical: if \code{TRUE}, statistically significant
 #'                    correlation coefficients are shown in boldface on the console.
 #' @param alpha       a numeric value between 0 and 1 indicating the significance
 #'                    level at which correlation coefficients are printed boldface
@@ -100,7 +100,8 @@
 #' Takuya Yanagida \email{takuya.yanagida@@univie.ac.at}
 #'
 #' @seealso
-#' \code{\link{multilevel.descript}}, \code{\link{multilevel.icc}}, \code{\link{cluster.scores}}
+#' \code{\link{write.result}}, \code{\link{multilevel.descript}}, \code{\link{multilevel.icc}},
+#' \code{\link{cluster.scores}}
 #'
 #' @references
 #' Hox, J., Moerbeek, M., & van de Schoot, R. (2018). \emph{Multilevel analysis:
@@ -128,6 +129,10 @@
 #' multilevel.cor(Demo.twolevel[, c("y1", "y2", "y3")],
 #'                cluster = Demo.twolevel$cluster)
 #'
+#' # Highlight statistically significant result at alpha = 0.05
+#' multilevel.cor(Demo.twolevel[, c("y1", "y2", "y3")], sig = TRUE,
+#'               cluster = Demo.twolevel$cluster)
+#'
 #' # Split output table in within-group and between-group correlation matrix.
 #' multilevel.cor(Demo.twolevel[, c("y1", "y2", "y3")],
 #'                cluster = Demo.twolevel$cluster, split = TRUE)
@@ -162,9 +167,14 @@
 #' mod <- multilevel.cor(Demo.twolevel[, c("y1", "y2", "y3")],
 #'                       cluster = Demo.twolevel$cluster, output = FALSE)
 #' lavaan::summary(mod$mod.fit, standardized = TRUE)
+#'
+#' # Write Results into a Excel file
+#' result <- multilevel.cor(Demo.twolevel[, c("y1", "y2", "y3")],
+#'                          cluster = Demo.twolevel$cluster, output = FALSE)
+#' write.result(result, "Multilevel_Correlation.xlsx")
 #' }
 multilevel.cor <- function(x, cluster, within = NULL, between = NULL, estimator = c("ML", "MLR"),
-                           na.omit = TRUE, sig = TRUE, alpha = 0.05,
+                           na.omit = TRUE, sig = FALSE, alpha = 0.05,
                            print = c("all", "cor", "se", "stat", "p"), split = FALSE,
                            tri = c("both", "lower", "upper"), tri.lower = TRUE,
                            p.adj = c("none", "bonferroni", "holm", "hochberg", "hommel", "BH", "BY", "fdr"),
